
%global forgeurl    https://github.com/AnalogJ/lexicon
Version:            3.17.0

%global pypi_name dns-lexicon

%bcond_with tests
%bcond_without extras

Name:           python-%{pypi_name}
Release:    1%{?dist}
Summary:        Manipulate DNS records on various DNS providers in a standardized/agnostic way

License:        MIT
URL:            %{forgeurl}
Source0:        lexicon-3.17.0.tar.gz
BuildArch:      noarch

BuildRequires:  python3-devel

%if %{with tests}
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-vcr
%endif


%description
Lexicon provides a way to manipulate DNS records on multiple DNS providers in a
standardized way. Lexicon has a CLI but it can also be used as a python
library.

%package -n     python3-%{pypi_name}
Summary:        %{summary}


Conflicts:      python3-lexicon

%if %{with extras}
Provides: python3dist(%{pypi_name}[easyname]) = %{version}
Provides: python%{python3_version}dist(%{pypi_name}[easyname]) = %{version}

Provides: python3dist(%{pypi_name}[gratisdns]) = %{version}
Provides: python%{python3_version}dist(%{pypi_name}[gratisdns]) = %{version}

Provides: python3dist(%{pypi_name}[henet]) = %{version}
Provides: python%{python3_version}dist(%{pypi_name}[henet]) = %{version}

Provides: python3dist(%{pypi_name}[hetzner]) = %{version}
Provides: python%{python3_version}dist(%{pypi_name}[hetzner]) = %{version}

Provides: python3dist(%{pypi_name}[plesk]) = %{version}
Provides: python%{python3_version}dist(%{pypi_name}[plesk]) = %{version}
%endif

%description -n python3-%{pypi_name}
Lexicon provides a way to manipulate DNS records on multiple DNS providers in a
standardized way. Lexicon has a CLI but it can also be used as a python
library.

This is the Python 3 version of the package.



%package -n     python3-%{pypi_name}+gransy
Summary:        Meta-package for python3-%{pypi_name} and gransy provider
Requires:       python3-%{pypi_name} = %{version}-%{release}

%description -n python3-%{pypi_name}+gransy
This package installs no files. It requires python3-%{pypi_name} and all
dependencies necessary to use the gransy provider.



%package -n     python3-%{pypi_name}+localzone
Summary:        Meta-package for python3-%{pypi_name} and localzone provider
Requires:       python3-%{pypi_name} = %{version}-%{release}

%description -n python3-%{pypi_name}+localzone
This package installs no files. It requires python3-%{pypi_name} and all
dependencies necessary to use the localzone provider.



%package -n     python3-%{pypi_name}+oci
Summary:        Meta-package for python3-%{pypi_name} and oci provider
Requires:       python3-%{pypi_name} = %{version}-%{release}

%description -n python3-%{pypi_name}+oci
This package installs no files. It requires python3-%{pypi_name} and all
dependencies necessary to use the oci provider.



%package -n     python3-%{pypi_name}+route53
Summary:        Meta-package for python3-%{pypi_name} and Route 53 provider
Requires:       python3-%{pypi_name} = %{version}-%{release}

%description -n python3-%{pypi_name}+route53
This package installs no files. It requires python3-%{pypi_name} and all
dependencies necessary to use the Route 53 provider.



%prep
%autosetup -n lexicon-%{version} -p1
rm -rf %{pypi_name}.egg-info

%if %{with extras}
%pyproject_buildrequires -r -t -e light -x gransy,localzone,oci,route53
%else
%pyproject_buildrequires -r -t -e light
%endif


%build
sed -i '1d' src/lexicon/_private/cli.py
%pyproject_wheel

%if %{with tests}
%check
TEST_SELECTOR="not AutoProviderTests and not NamecheapProviderTests and not NamecheapManagedProviderTests and not Route53Provider and not AliyunProviderTests and not AuroraProviderTests and not Route53ProviderTests"

TEST_SELECTOR+=" and not SoftLayerProviderTests"
%if %{without extras}
TEST_SELECTOR+=" and not DDNSProviderTests and not DuckdnsProviderTests and not GransyProviderTests and not LocalzoneProviderTests and not OciProviderTests and not OciInstancePrincipalProviderTests and not Route53ProviderTests"
%endif
%pytest -v -k "${TEST_SELECTOR}"
%endif

%install
%pyproject_install
install -pm 0755 %{buildroot}/%{_bindir}/lexicon %{buildroot}/%{_bindir}/lexicon-%{python3_version}
cd %{buildroot}/%{_bindir}
ln -s lexicon-%{python3_version} lexicon-3
rm -rf %{buildroot}%{python3_sitelib}/lexicon/tests


%files -n python3-%{pypi_name}
%license LICENSE
%doc README.rst
%{_bindir}/lexicon
%{_bindir}/lexicon-3
%{_bindir}/lexicon-%{python3_version}
%{python3_sitelib}/lexicon
%{python3_sitelib}/dns_lexicon-%{version}.dist-info

%if %{with extras}

%files -n python3-%{pypi_name}+gransy
%{?python_extras_subpkg:%ghost %{python3_sitelib}/dns_lexicon-%{version}.dist-info}

%files -n python3-%{pypi_name}+localzone
%{?python_extras_subpkg:%ghost %{python3_sitelib}/dns_lexicon-%{version}.dist-info}

%files -n python3-%{pypi_name}+oci
%{?python_extras_subpkg:%ghost %{python3_sitelib}/dns_lexicon-%{version}.dist-info}

%files -n python3-%{pypi_name}+route53
%{?python_extras_subpkg:%ghost %{python3_sitelib}/dns_lexicon-%{version}.dist-info}

%endif

%changelog
* Fri Jun 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.17.0-1
- initial build
